""" Tests that we can receive information about what exams where written """

from django.urls import reverse
from rest_framework import status
from rest_framework.test import (APIRequestFactory, APITestCase,
                                 force_authenticate)

from core.models import ExamType
from core.views import ExamApiViewSet
from util.factories import GradyUserFactory


class ExamListTest(APITestCase):

    @classmethod
    def setUpTestData(cls):
        cls.factory = APIRequestFactory()
        cls.user_factory = GradyUserFactory()

    def setUp(self):
        self.request = self.factory.get(reverse('examtype-list'))
        force_authenticate(self.request,
                           self.user_factory.make_reviewer().user)
        self.view = ExamApiViewSet.as_view({'get': 'list'})
        self.response = self.view(self.request)

    def test_can_access_when_authenticated(self):
        self.assertEqual(self.response.status_code, status.HTTP_200_OK)

    def test_getting_all_available_exams(self):
        self.assertEqual(ExamType.objects.count(), len(self.response.data))
